from unity import *
from flightgroup import FlightGroup

import Objective


#arthixGo = GameObject("Mavrin Expanse")
#arthixGo = GameObject("The Barrens")
#arthixGo = GameObject("Peraveeno System")
arthixGo = GameObject("Haath System")
arthix = arthixGo.AddComponent("Venue")
# arthixGo.transform.position = Vector3(50000, 0, 0)

archer = FlightGroup("Archer", "Raptor", 12, 4, "Ruuvian")
archer.startPosition(arthix, 0, Vector3(500, 60, 100))
archer.playerControlled()

lancer = FlightGroup("Lancer", "Medium Transport", 4, 4, "Ruuvian")
lancer.startPosition(arthix, 0, Vector3(550, 10, 160))

# phalanx = FlightGroup("Phalanx", "Hawk", 16, 8, "Ruuvian")
# phalanx.startPosition(arthix, 0, Vector3(-700, 100, -100))
# phalanx.initialDelay = 15

vicious = FlightGroup("Vicious", "Assault Corvette", 1, 1, "Fesande")
vicious.startPosition(arthix, 120, Vector3(-1700, 200, -200))

rethan = FlightGroup("Rethan", "Falcon", 4, 2, "Fesande")
rethan.startPosition(arthix, 25, Vector3(-1700, 0, -100))

armos = FlightGroup("Armos", "Hawk", 8, 4, "Fesande")
armos.startPosition(arthix, 15, Vector3(-1550, 300, 100))

lancer.addObjective(vicious.fg, 1.0, Objective.FlightGroupState.DESTROYED)
rethan.addObjective(vicious.fg, 1.0, Objective.FlightGroupState.SURVIVE)
rethan.addObjective(lancer.fg, 0.5, Objective.FlightGroupState.DESTROYED)
armos.addObjective(lancer.fg, 0.5, Objective.FlightGroupState.DESTROYED)
vicious.addObjective(lancer.fg, 1.0, Objective.FlightGroupState.DESTROYED)


